# prismataengine

This is a package that provides access to Dave Churchill's Prismata Engine from Python.

# Requirements

- Boost-Python

# Install
The usual way:
```
pip install prismataengine
```

Or from source:
```
hub clone --recurse-submodules smkravec/prismataengine
cd prismataengine
python setup.py install
```
